"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const tap_bark_1 = require("../tap-bark/src/tap-bark");
const alsatian_core_1 = require("../core/alsatian-core");
class CliTestRunner {
    constructor(_testRunner) {
        this._testRunner = _testRunner;
        if (!_testRunner) {
            throw new TypeError("_testRunner must not be null or undefined.");
        }
    }
    static create() {
        const outputStream = new alsatian_core_1.TestOutputStream();
        const testRunner = new alsatian_core_1.TestRunner(outputStream);
        return new CliTestRunner(testRunner);
    }
    run(userArguments) {
        return __awaiter(this, void 0, void 0, function* () {
            const packageJson = require("../package.json");
            // if version has been requested then output the current version and exit
            if (userArguments.versionRequested) {
                process.stdout.write("alsatian version " + packageJson.version);
                return;
            }
            // if help has been requested then output info about using the CLI and exit
            if (userArguments.helpRequested) {
                process.stdout.write("\n\n" +
                    "alsatian version " +
                    packageJson.version +
                    "\n" +
                    "=========================\n" +
                    "CLI options\n" +
                    "=========================\n" +
                    "HELP:    --help / -h                      " +
                    "(outputs CLI information)\n" +
                    "VERSION: --version / -v                   " +
                    "(outputs the version of the CLI)\n" +
                    "TAP:     --tap / -T                       " +
                    "(runs alsatian with TAP output)\n" +
                    "TIMEOUT: --timeout [number] / -t [number] " +
                    "(sets the timeout period for tests in milliseconds - default 500)\n" +
                    "\n");
                return;
            }
            // create test set from given file globs
            const testSet = alsatian_core_1.TestSet.create();
            testSet.addTestsFromFiles(userArguments.fileGlobs);
            if (userArguments.tap) {
                // if they want TAP output then just write to stdout directly
                this._testRunner.outputStream.pipe(process.stdout);
            }
            else {
                // otherwise create the tap bark reporter
                const bark = tap_bark_1.TapBark.create();
                // pipe the reporter into stdout
                this._testRunner.outputStream
                    .pipe(bark.getPipeable())
                    .pipe(process.stdout);
            }
            try {
                yield this._testRunner.run(testSet, userArguments.timeout);
            }
            catch (error) {
                this._handleTestSetRunError(error);
            }
        });
    }
    _handleTestSetRunError(error) {
        process.stderr.write(error.message + "\n");
        process.exit(1);
    }
}
exports.CliTestRunner = CliTestRunner;
//# sourceMappingURL=cli-test-runner.js.map