"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const matchers_1 = require("../matchers");
const fail_1 = require("./fail");
const matchers_2 = require("../matchers");
const spying_1 = require("../spying");
function buildExpect() {
    const EXPECT = ExpectFunction;
    EXPECT.fail = fail_1.fail;
    EXPECT.extend = ((a, b) => {
        MATCHER_MAP.push([a, b]);
        return EXPECT;
    });
    return EXPECT;
}
exports.buildExpect = buildExpect;
const MATCHER_MAP = [
    [Array, matchers_1.ContainerMatcher],
    [spying_1.FunctionSpy, matchers_1.FunctionMatcher],
    [spying_1.PropertySpy, matchers_1.PropertyMatcher],
    [Object, matchers_1.EmptyMatcher]
];
function ExpectFunction(actualValue) {
    const MATCHER = findMatcher(actualValue);
    return new MATCHER(actualValue);
}
function getStack() {
    return new Error().stack.split("\n").map(stackLine => {
        const STACK_ITEMS = stackLine
            .replace(/^\s*at (.+) \((.+):\d+:\d+\)$/, "$1 $2")
            .split(" ");
        return {
            functionName: STACK_ITEMS[0],
            filePath: STACK_ITEMS[1]
        };
    });
}
function findMatcher(actualValue) {
    if (typeof actualValue === "function") {
        return matchers_1.FunctionMatcher;
    }
    if (typeof actualValue === "string") {
        return matchers_1.StringMatcher;
    }
    if (typeof actualValue === "number") {
        return matchers_1.NumberMatcher;
    }
    if (actualValue === null || actualValue === undefined) {
        return matchers_2.Matcher;
    }
    const proto = Object.getPrototypeOf(actualValue);
    if (proto === null) {
        return matchers_2.Matcher;
    }
    const match = MATCHER_MAP.find(x => x[0] === proto.constructor);
    return match ? match[1] : findMatcher(proto);
}
//# sourceMappingURL=build-expect.js.map