"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const matcher_1 = require("./matcher");
const stringification_1 = require("../stringification");
/**
 * Compares types that can be empty e.g. string, object and Array
 */
class EmptyMatcher extends matcher_1.Matcher {
    /**
     * Checks that an array is empty, a string is empty, or an object literal has no properties
     */
    toBeEmpty() {
        const actualValue = this.actualValue;
        const length = actualValue instanceof Map
            ? actualValue.size
            : actualValue.length !== undefined
                ? actualValue.length
                : Object.keys(actualValue).length;
        this._registerMatcher((length === 0) === this.shouldMatch, `Expected "${typeof actualValue === "string"
            ? actualValue
            : stringification_1.stringify(this.actualValue)}" ` + `${this.shouldMatch ? "" : "not "}to be empty.`, this.actualValue);
    }
}
exports.EmptyMatcher = EmptyMatcher;
//# sourceMappingURL=empty-matcher.js.map