"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const errors_1 = require("../errors");
const _1 = require("./");
class FunctionSpyMatcher {
    constructor(spy, expectedArguments) {
        this._expectedArguments = null;
        if (spy === null || spy === undefined) {
            throw new TypeError("spy must not be null or undefined.");
        }
        if (expectedArguments) {
            this._expectedArguments = expectedArguments;
        }
        this._spy = spy;
    }
    exactly(expectedCallCount) {
        this._validateCallCount(expectedCallCount, "expectedCallCount");
        this._throwCallCountError(count => count !== expectedCallCount, expectedCallCount, _1.SpyCallCountType.Exactly, true);
        return new _1.FunctionSpyCallCountMatcher();
    }
    anythingBut(unexpectedCallCount) {
        this._validateCallCount(unexpectedCallCount, "unexpectedCallCount");
        this._throwCallCountError(count => count === unexpectedCallCount, unexpectedCallCount, _1.SpyCallCountType.Exactly, false);
        return new _1.FunctionSpyCallCountMatcher();
    }
    greaterThan(minimumCallCount) {
        this._validateCallCount(minimumCallCount, "minimumCallCount");
        this._throwCallCountError(count => count <= minimumCallCount, minimumCallCount, _1.SpyCallCountType.GreaterThan, true);
        return new _1.FunctionSpyCallCountMatcher();
    }
    lessThan(maximumCallCount) {
        this._validateCallCount(maximumCallCount, "maximumCallCount");
        this._throwCallCountError(count => count >= maximumCallCount, maximumCallCount, _1.SpyCallCountType.LessThan, true);
        return new _1.FunctionSpyCallCountMatcher();
    }
    _validateCallCount(callCount, callCountName) {
        if (callCount < 1) {
            throw new TypeError(`${callCountName} must be greater than 0.`);
        }
    }
    _matchingCallsCount() {
        if (this._expectedArguments === null) {
            return this._spy.calls.length;
        }
        return this._matchingArguments();
    }
    _matchingArguments() {
        return this._spy.callsWithArguments.apply(this._spy, this._expectedArguments).length;
    }
    _throwCallCountError(countIsNotCorrect, callCount, callCountType, shouldMatch) {
        if (countIsNotCorrect(this._matchingCallsCount())) {
            throw new errors_1.FunctionCallCountMatchError(this._spy, shouldMatch, callCount, callCountType, this._expectedArguments);
        }
    }
}
exports.FunctionSpyMatcher = FunctionSpyMatcher;
//# sourceMappingURL=function-spy-matcher.js.map