"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const test_item_1 = require("./test-item");
class TestPlan {
    constructor(testSet) {
        this._testItems = [];
        if (testSet.testFixtures.length === 0) {
            return;
        }
        const testFixtures = testSet.testFixtures;
        // are there any tests or test fixtures focussed
        const focussedTestsOrTestFixtures = testFixtures.filter(testFixture => testFixture.focussed || testFixture.tests.some(test => test.focussed)).length > 0;
        testFixtures.forEach(testFixture => {
            // run all tests if no tests or fixtures anywhere are focussed
            let testsToRun = testFixture.tests;
            // otherwise if there are tests or fixtures focussed
            if (focussedTestsOrTestFixtures) {
                // if any of the tests are focussed choose just those
                if (testFixture.tests.some(test => test.focussed)) {
                    testsToRun = testFixture.tests.filter(test => test.focussed);
                }
                else if (testFixture.focussed === false) {
                    // if no tests are focussed and the fixture itself is not focussed run no tests
                    testsToRun = [];
                }
            }
            testsToRun.forEach(test => {
                test.testCases.forEach(testCase => {
                    this._testItems.push(new test_item_1.TestItem(testFixture, test, testCase));
                });
            });
        });
    }
    get testItems() {
        return this._testItems;
    }
}
exports.TestPlan = TestPlan;
//# sourceMappingURL=test-plan.js.map